@@ -1,4 +1,4 @@
-/* $Id: SUPDrvInternal.h 95888 2014-09-05 09:02:05Z fmehnert $ */
+/* $Id: SUPDrvInternal.h 98021 2015-02-04 07:44:52Z fmehnert $ */
 /** @file
  * VirtualBox Support Driver - Internal header.
  */
@@ -548,6 +548,8 @@ typedef struct SUPDRVDEVEXT
 
     /** Linked list of loaded code. */
     PSUPDRVLDRIMAGE volatile        pLdrImages;
+    /** Set if the image loading interface got disabled after loading all needed images */
+    bool                            fLdrLockedDown;
 
     /** @name These members for detecting whether an API caller is in ModuleInit.
      * Certain APIs are only permitted from ModuleInit, like for instance tracepoint
