@@ -1,4 +1,4 @@
-/* $Id: log-vbox.cpp 89632 2013-10-07 21:19:37Z bird $ */
+/* $Id: log-vbox.cpp 93776 2014-05-20 08:33:27Z aeichner $ */
 /** @file
  * VirtualBox Runtime - Logging configuration.
  */
@@ -231,7 +231,6 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
     ASSERT_LOG_GROUP(DEV_RTC);
     ASSERT_LOG_GROUP(DEV_SERIAL);
     ASSERT_LOG_GROUP(DEV_SMC);
-    ASSERT_LOG_GROUP(DEV_USB);
     ASSERT_LOG_GROUP(DEV_VGA);
     ASSERT_LOG_GROUP(DEV_VMM);
     ASSERT_LOG_GROUP(DEV_VMM_STDERR);
@@ -257,6 +256,7 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
     ASSERT_LOG_GROUP(HGCM);
     ASSERT_LOG_GROUP(HM);
     ASSERT_LOG_GROUP(IOM);
+    ASSERT_LOG_GROUP(LWIP);
     ASSERT_LOG_GROUP(MAIN);
     ASSERT_LOG_GROUP(MM);
     ASSERT_LOG_GROUP(MM_HEAP);
